pub enum PaymentMethodType {
Show 21 variants
Alipay,
ApplePay,
Bancontact,
Blik,
Card,
GooglePay,
Ideal,
KakaoPay,
KoreaLocal,
SouthKoreaLocalCard,
MbWay,
NaverPay,
Offline,
Payco,
Paypal,
Pix,
SamsungPay,
Unknown,
Upi,
WechatPay,
WireTransfer,
}Expand description
Type of payment method used for this payment attempt.
Variants
Alipay
Alipay, popular in China.
ApplePay
Apple Pay on a supported Apple device.
Bancontact
Bancontact, popular in Belgium.
Blik
BLIK, a popular payment method in Poland.
Card
Credit or debit card.
GooglePay
Google Pay on a supported Android device, Chromebook, or Google Chrome browser.
Ideal
iDEAL, popular in the Netherlands.
KakaoPay
Kakao Pay, a popular payment method in Korea.
KoreaLocal
Korean payment methods, which includes over 20 payment options for the Korean market. Check underlying_payment_method.korea_local for information about the Korean payment method used to pay.
SouthKoreaLocalCard
Korean local credit or debit card.
MbWay
MB WAY, a popular payment method in Portugal.
Naver Pay, a popular payment method in Korea.
Offline
Payment recorded offline.
Payco
Payco, a popular payment method in Korea.
Paypal
PayPal.
Pix
Pix, popular in Brazil. Available in early access.
SamsungPay
Samsung Pay, a popular payment method in Korea.
Unknown
Payment method not known.
Upi
Unified Payments Interface (UPI), popular in India. Available in early access.
WechatPay
WeChat Pay, a popular payment method in China.
WireTransfer
Wire transfer, sometimes called bank transfer.