pub enum SubscriptionInclude {
NextTransaction,
RecurringTransactionDetails,
}Expand description
Include related entities in the response.
Variants
NextTransaction
Include an object with a preview of the next transaction for this subscription. May include prorated charges that aren’t yet billed and one-time charges.
RecurringTransactionDetails
Include an object with a preview of the recurring transaction for this subscription. This is what the customer can expect to be billed when there are no prorated or one-time charges.