pub struct TransactionUpdate<'a> { /* private fields */ }Expand description
Request builder for updating a transaction.
Implementations
Sourceimpl<'a> TransactionUpdate<'a>
impl<'a> TransactionUpdate<'a>
pub fn new(client: &'a Paddle, transaction_id: impl Into<TransactionID>) -> Self
Sourcepub fn include(
&mut self,
entities: impl IntoIterator<Item = impl AsRef<str>>,
) -> &mut Self
pub fn include( &mut self, entities: impl IntoIterator<Item = impl AsRef<str>>, ) -> &mut Self
Include related entities in the response.
Valid values are:
addressadjustmentsadjustments_totalsavailable_payment_methodsbusinesscustomerdiscount
Sourcepub fn status(
&mut self,
status: impl Into<Nullable<TransactionStatus>>,
) -> &mut Self
pub fn status( &mut self, status: impl Into<Nullable<TransactionStatus>>, ) -> &mut Self
Status of this transaction. You may set a transaction to billed or canceled. Billed transactions cannot be changed.
For manually-collected transactions, marking as billed is essentially issuing an invoice.
Sourcepub fn customer_id(
&mut self,
customer_id: impl Into<Nullable<CustomerID>>,
) -> &mut Self
pub fn customer_id( &mut self, customer_id: impl Into<Nullable<CustomerID>>, ) -> &mut Self
Paddle ID of the customer that this transaction is for.
Sourcepub fn address_id(
&mut self,
address_id: impl Into<Nullable<AddressID>>,
) -> &mut Self
pub fn address_id( &mut self, address_id: impl Into<Nullable<AddressID>>, ) -> &mut Self
Paddle ID of the address that this transaction is for.
Sourcepub fn business_id(
&mut self,
business_id: impl Into<Nullable<BusinessID>>,
) -> &mut Self
pub fn business_id( &mut self, business_id: impl Into<Nullable<BusinessID>>, ) -> &mut Self
Paddle ID of the business that this transaction is for.
Sourcepub fn custom_data(
&mut self,
custom_data: impl Into<Nullable<HashMap<String, String>>>,
) -> &mut Self
pub fn custom_data( &mut self, custom_data: impl Into<Nullable<HashMap<String, String>>>, ) -> &mut Self
Your own structured key-value data.
Sourcepub fn currency_code(
&mut self,
currency_code: impl Into<Nullable<CurrencyCode>>,
) -> &mut Self
pub fn currency_code( &mut self, currency_code: impl Into<Nullable<CurrencyCode>>, ) -> &mut Self
Supported three-letter currency code. Must be USD, EUR, or GBP if collection_mode is manual.
Sourcepub fn collection_mode(
&mut self,
mode: impl Into<Nullable<CollectionMode>>,
) -> &mut Self
pub fn collection_mode( &mut self, mode: impl Into<Nullable<CollectionMode>>, ) -> &mut Self
How payment is collected for this transaction. automatic for checkout, manual for invoices.
Sourcepub fn discount_id(
&mut self,
discount_id: impl Into<Nullable<DiscountID>>,
) -> &mut Self
pub fn discount_id( &mut self, discount_id: impl Into<Nullable<DiscountID>>, ) -> &mut Self
Paddle ID of the discount applied to this transaction.
Sourcepub fn billing_details(
&mut self,
billing_details: impl Into<Nullable<BillingDetails>>,
) -> &mut Self
pub fn billing_details( &mut self, billing_details: impl Into<Nullable<BillingDetails>>, ) -> &mut Self
Details for invoicing. Required if collection_mode is manual.
Sourcepub fn billing_period(
&mut self,
billing_period: impl Into<Nullable<TimePeriod>>,
) -> &mut Self
pub fn billing_period( &mut self, billing_period: impl Into<Nullable<TimePeriod>>, ) -> &mut Self
Time period that this transaction is for. Set automatically by Paddle for subscription renewals to describe the period that charges are for.
pub fn items( &mut self, items: impl Into<Nullable<Vec<TransactionItem>>>, ) -> &mut Self
Sourcepub fn checkout_url(&mut self, url: impl Into<Nullable<String>>) -> &mut Self
pub fn checkout_url(&mut self, url: impl Into<Nullable<String>>) -> &mut Self
Paddle Checkout URL for creating or updating an automatically-collected transaction, or when creating or updating a manually-collected transaction
where billing_details.enable_checkout is true.
Pass the URL for an approved domain, or null to set to your default payment URL.
Paddle returns a unique payment link composed of the URL passed or your default payment URL + ?_ptxn= and the Paddle ID for this transaction.
Sourcepub async fn send(&self) -> Result<SuccessResponse<Transaction>, Error>
pub async fn send(&self) -> Result<SuccessResponse<Transaction>, Error>
Send the request to Paddle and return the response.